require "#{File.dirname(__FILE__)}/../lib/spec_helper.rb"

describe 'Endpoints behind CSRF protection' do

  before :all do
    # If the tests previously failed, logging in will redirect to the wrong
    # page. This ensures that we are at the main page at the beginning of this
    # test, so that it will not fail while trying to create the test class,
    # group, and node.
    visit_dashboard
  end

  describe 'without valid csrf token' do

    before :each do
      visit_dashboard
    end

    after :each do
      logout
    end

    it 'should not be able to delete a class' do
      create_class('test_class1')
      js = "jQuery.post('#{TestConfig.base_url}/node_classes/test_class1', {_method: 'delete'}).fail(function(ret) { if (ret.status === 422) { window.test = true; }});"
      csrf_test(js)
    end

    it 'should not be able to delete a group' do
      create_group('test_group1')
      js = "jQuery.post('#{TestConfig.base_url}/node_groups/test_group1', {_method: 'delete'}).fail(function(ret) { if (ret.status === 422) { window.test = true; }});"
      csrf_test(js)
    end

    it 'should not be able to delete a node' do
      create_node('test_node1')
      js = "jQuery.post('#{TestConfig.base_url}/nodes/test_node1', {_method: 'delete'}).fail(function(ret) { if (ret.status === 422) { window.test = true; }});"
      csrf_test(js)
    end

    it 'should not be able to delete a report' do
      js = "jQuery.post('#{TestConfig.base_url}/reports/1', {_method: 'delete'}).fail(function(ret) { if (ret.status === 422) { window.test = true; }});"
      csrf_test(js)
    end

    # We must be able to upload reports without a CSRF token, since this is
    # what the Puppet Master does.
    it 'should be able to upload a report' do
      js = "jQuery.post('#{TestConfig.base_url}/reports/upload').done(function() { window.test = true; });"
      csrf_test(js)
    end

    it 'should be able to PUT a node as a basic auth user' do
      command = `/usr/bin/curl -k -X PUT -u #{default_credentials[:username]}:#{default_credentials[:password]} #{TestConfig.base_url}/nodes/test_node1`
      JSON.parse(command)['status'].should == 'ok'
    end
  end

end
